/*
  AntiRight
  (c) 2002-2007 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef GSH_CALLBACKS_H
#define GSH_CALLBACKS_H

struct GSHCBData
{
	struct GSH *gsh;
	gpointer data;
	void (*delete)(struct GSHCBData *);
	void (*system)(GtkWidget *, gpointer);
	void (*entry)(GtkWidget *, gpointer);
};

struct GSHCBData *
gsh_new_GSHCBData(struct GSH * gsh, gpointer data);

#define GSH_TEST_EXIT(gsh_arg)\
{\
	struct GSH * gsh = gsh_arg;\
	if (GSH_FLAG(GSH_CBEXIT))\
		gtk_main_quit();\
}

void
gsh_send_signal(GtkWidget * widget, const gchar * signal_name);

#endif /* not GSH_CALLBACKS_H */
